@@ -11,6 +11,11 @@ try:
     from spgl1 import spgl1
 except ModuleNotFoundError:
     spgl1 = None
+    spgl1_message = 'Spgl1 not installed. ' \
+                    'Run "pip install spgl1".'
+except Exception as e:
+    spgl1 = None
+    spgl1_message = 'Failed to import spgl1 (error:%s).' % e
 
 
 def _softthreshold(x, thresh):
@@ -205,9 +210,9 @@ def OMP(Op, data, niter_outer=10, niter_inner=40, sigma=1e-4,
     normalizecols : :obj:`list`
         Normalize columns (``True``) or not (``False``). Note that this can be
         expensive as it requires applying the forward operator
-        :math:`n_{cols}`times to unit vectors (i.e., containing 1 at position j
-        and zero otherwise); use only when the columns of the operator are
-        expected to have highly varying norms.
+        :math:`n_{cols}` times to unit vectors (i.e., containing 1 at
+        position j and zero otherwise); use only when the columns of the
+        operator are expected to have highly varying norms.
     show : :obj:`bool`, optional
         Display iterations log
 
@@ -745,7 +750,7 @@ def SPGL1(Op, data, SOp=None, tau=0, sigma=0, x0=None, **kwargs_spgl1):
 
     """
     if spgl1 is None:
-        raise ModuleNotFoundError('spgl1 not installed')
+        raise ModuleNotFoundError(spgl1_message)
     pinv, _, _, info = \
         spgl1(Op if SOp is None else Op*SOp.H, data,
               tau=tau, sigma=sigma, x0=x0, **kwargs_spgl1)
