@@ -2,5 +2,7 @@ from .mdd import MDC
 from .mdd import MDD
 from .marchenko import Marchenko
 from .seismicinterpolation import SeismicInterpolation
-from .wavedecomposition import UpDownComposition2D, WavefieldDecomposition
+from .wavedecomposition import PressureToVelocity, UpDownComposition2D, \
+    UpDownComposition3D, WavefieldDecomposition
+from .oneway import PhaseShift
 from .lsm import Demigration, LSM
